Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'org.eclipse.mylyn.bugzilla.ui/src/org')
-rw-r--r--org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/BugzillaHyperLink.java2
-rw-r--r--org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/BugzillaResultMatchAdapter.java6
-rw-r--r--org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/BugzillaTaskHyperlinkDetector.java2
-rw-r--r--org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/editor/BugzillaTaskEditor.java39
-rw-r--r--org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/editor/NewBugzillaTaskEditor.java4
-rw-r--r--org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/search/BugzillaSearchPage.java7
-rw-r--r--org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/search/IBugzillaResultEditorMatchAdapter.java2
-rw-r--r--org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaCustomQueryWizardPage.java2
-rw-r--r--org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaRepositorySettingsPage.java4
-rw-r--r--org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaRepositoryUi.java8
-rw-r--r--org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaTaskEditorFactory.java17
-rw-r--r--org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaTaskEditorInput.java2
-rw-r--r--org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaTaskExternalizer.java14
-rw-r--r--org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/EditBugzillaQueryWizard.java2
-rw-r--r--org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/NewBugzillaQueryWizard.java2
-rw-r--r--org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/wizard/BugzillaProductPage.java39
-rw-r--r--org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/wizard/NewBugzillaTaskWizard.java21
17 files changed, 77 insertions, 96 deletions
diff --git a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/BugzillaHyperLink.java b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/BugzillaHyperLink.java
index d64a24ffe..bf28e01ce 100644
--- a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/BugzillaHyperLink.java
+++ b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/BugzillaHyperLink.java
@@ -14,7 +14,7 @@ import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.text.IRegion;
import org.eclipse.jface.text.hyperlink.IHyperlink;
import org.eclipse.mylar.internal.bugzilla.core.IBugzillaConstants;
-import org.eclipse.mylar.internal.tasks.ui.TasksUiUtil;
+import org.eclipse.mylar.tasks.ui.TasksUiUtil;
/**
* @author Mik Kersten
diff --git a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/BugzillaResultMatchAdapter.java b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/BugzillaResultMatchAdapter.java
index d7c202548..7d2a27d8e 100644
--- a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/BugzillaResultMatchAdapter.java
+++ b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/BugzillaResultMatchAdapter.java
@@ -12,9 +12,9 @@
package org.eclipse.mylar.internal.bugzilla.ui;
import org.eclipse.mylar.internal.bugzilla.ui.search.IBugzillaResultEditorMatchAdapter;
-import org.eclipse.mylar.internal.tasks.ui.editors.AbstractTaskEditorInput;
-import org.eclipse.mylar.internal.tasks.ui.editors.RepositoryTaskEditorInput;
-import org.eclipse.mylar.internal.tasks.ui.search.RepositorySearchResult;
+import org.eclipse.mylar.tasks.ui.editors.AbstractTaskEditorInput;
+import org.eclipse.mylar.tasks.ui.editors.RepositoryTaskEditorInput;
+import org.eclipse.mylar.tasks.ui.search.RepositorySearchResult;
import org.eclipse.search.ui.text.AbstractTextSearchResult;
import org.eclipse.search.ui.text.Match;
import org.eclipse.ui.IEditorInput;
diff --git a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/BugzillaTaskHyperlinkDetector.java b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/BugzillaTaskHyperlinkDetector.java
index 5e59cb9f0..361ea2bd6 100644
--- a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/BugzillaTaskHyperlinkDetector.java
+++ b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/BugzillaTaskHyperlinkDetector.java
@@ -17,8 +17,8 @@ import org.eclipse.jface.text.IRegion;
import org.eclipse.jface.text.ITextViewer;
import org.eclipse.jface.text.hyperlink.IHyperlink;
import org.eclipse.jface.text.hyperlink.IHyperlinkDetector;
-import org.eclipse.mylar.internal.tasks.ui.editors.RepositoryTextViewer;
import org.eclipse.mylar.tasks.core.TaskRepository;
+import org.eclipse.mylar.tasks.ui.editors.RepositoryTextViewer;
/**
* @author Rob Elves
diff --git a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/editor/BugzillaTaskEditor.java b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/editor/BugzillaTaskEditor.java
index fbbe8e2dd..367fa1519 100644
--- a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/editor/BugzillaTaskEditor.java
+++ b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/editor/BugzillaTaskEditor.java
@@ -27,21 +27,20 @@ import org.eclipse.mylar.internal.bugzilla.core.BugzillaReportElement;
import org.eclipse.mylar.internal.bugzilla.core.IBugzillaConstants;
import org.eclipse.mylar.internal.bugzilla.ui.BugzillaUiPlugin;
import org.eclipse.mylar.internal.tasks.ui.TaskListColorsAndFonts;
-import org.eclipse.mylar.internal.tasks.ui.TasksUiUtil;
-import org.eclipse.mylar.internal.tasks.ui.editors.AbstractRepositoryTaskEditor;
-import org.eclipse.mylar.internal.tasks.ui.editors.AbstractTaskEditorInput;
-import org.eclipse.mylar.internal.tasks.ui.editors.MylarTaskEditor;
-import org.eclipse.mylar.internal.tasks.ui.editors.RepositoryTaskEditorInput;
-import org.eclipse.mylar.internal.tasks.ui.editors.RepositoryTaskOutlineNode;
-import org.eclipse.mylar.internal.tasks.ui.editors.RepositoryTaskSelection;
-import org.eclipse.mylar.internal.tasks.ui.views.DatePicker;
-import org.eclipse.mylar.internal.tasks.ui.views.TaskRepositoriesView;
import org.eclipse.mylar.tasks.core.AbstractRepositoryTask;
import org.eclipse.mylar.tasks.core.ITask;
import org.eclipse.mylar.tasks.core.RepositoryTaskAttribute;
import org.eclipse.mylar.tasks.core.RepositoryTaskData;
import org.eclipse.mylar.tasks.core.TaskComment;
+import org.eclipse.mylar.tasks.ui.DatePicker;
import org.eclipse.mylar.tasks.ui.TasksUiPlugin;
+import org.eclipse.mylar.tasks.ui.TasksUiUtil;
+import org.eclipse.mylar.tasks.ui.editors.AbstractRepositoryTaskEditor;
+import org.eclipse.mylar.tasks.ui.editors.AbstractTaskEditorInput;
+import org.eclipse.mylar.tasks.ui.editors.RepositoryTaskEditorInput;
+import org.eclipse.mylar.tasks.ui.editors.RepositoryTaskOutlineNode;
+import org.eclipse.mylar.tasks.ui.editors.RepositoryTaskSelection;
+import org.eclipse.mylar.tasks.ui.editors.TaskEditor;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
@@ -220,8 +219,8 @@ public class BugzillaTaskEditor extends AbstractRepositoryTaskEditor {
// "Show dependency tree", SWT.NONE);
// showDependencyTree.addHyperlinkListener(new HyperlinkAdapter() {
// public void linkActivated(HyperlinkEvent e) {
- // if (ExistingBugEditor.this.getEditor() instanceof MylarTaskEditor) {
- // MylarTaskEditor mylarTaskEditor = (MylarTaskEditor)
+ // if (ExistingBugEditor.this.getEditor() instanceof TaskEditor) {
+ // TaskEditor mylarTaskEditor = (TaskEditor)
// ExistingBugEditor.this.getEditor();
// mylarTaskEditor.displayInBrowser(repository.getUrl() +
// IBugzillaConstants.DEPENDENCY_TREE_URL
@@ -239,8 +238,8 @@ public class BugzillaTaskEditor extends AbstractRepositoryTaskEditor {
// "Show dependency graph", SWT.NONE);
// showDependencyGraph.addHyperlinkListener(new HyperlinkAdapter() {
// public void linkActivated(HyperlinkEvent e) {
- // if (ExistingBugEditor.this.getEditor() instanceof MylarTaskEditor) {
- // MylarTaskEditor mylarTaskEditor = (MylarTaskEditor)
+ // if (ExistingBugEditor.this.getEditor() instanceof TaskEditor) {
+ // TaskEditor mylarTaskEditor = (TaskEditor)
// ExistingBugEditor.this.getEditor();
// mylarTaskEditor.displayInBrowser(repository.getUrl() +
// IBugzillaConstants.DEPENDENCY_GRAPH_URL
@@ -258,7 +257,7 @@ public class BugzillaTaskEditor extends AbstractRepositoryTaskEditor {
addKeywordsList(composite);
} catch (IOException e) {
MessageDialog.openInformation(null, "Attribute Display Error",
- "Could not retrieve keyword list, ensure proper configuration in " + TaskRepositoriesView.NAME
+ "Could not retrieve keyword list, ensure proper configuration in " + TasksUiPlugin.LABEL_VIEW_REPOSITORIES
+ "\n\nError reported: " + e.getMessage());
}
@@ -278,8 +277,8 @@ public class BugzillaTaskEditor extends AbstractRepositoryTaskEditor {
viewActivity.addHyperlinkListener(new HyperlinkAdapter() {
@Override
public void linkActivated(HyperlinkEvent e) {
- if (BugzillaTaskEditor.this.getEditor() instanceof MylarTaskEditor) {
- MylarTaskEditor mylarTaskEditor = (MylarTaskEditor) BugzillaTaskEditor.this.getEditor();
+ if (BugzillaTaskEditor.this.getEditor() instanceof TaskEditor) {
+ TaskEditor mylarTaskEditor = (TaskEditor) BugzillaTaskEditor.this.getEditor();
mylarTaskEditor.displayInBrowser(repository.getUrl() + IBugzillaConstants.URL_BUG_ACTIVITY
+ getRepositoryTaskData().getId());
}
@@ -618,8 +617,8 @@ public class BugzillaTaskEditor extends AbstractRepositoryTaskEditor {
showVotesHyperlink.addHyperlinkListener(new HyperlinkAdapter() {
@Override
public void linkActivated(HyperlinkEvent e) {
- if (BugzillaTaskEditor.this.getEditor() instanceof MylarTaskEditor) {
- MylarTaskEditor mylarTaskEditor = (MylarTaskEditor) BugzillaTaskEditor.this.getEditor();
+ if (BugzillaTaskEditor.this.getEditor() instanceof TaskEditor) {
+ TaskEditor mylarTaskEditor = (TaskEditor) BugzillaTaskEditor.this.getEditor();
mylarTaskEditor.displayInBrowser(repository.getUrl() + IBugzillaConstants.URL_SHOW_VOTES
+ getRepositoryTaskData().getId());
}
@@ -630,8 +629,8 @@ public class BugzillaTaskEditor extends AbstractRepositoryTaskEditor {
voteHyperlink.addHyperlinkListener(new HyperlinkAdapter() {
@Override
public void linkActivated(HyperlinkEvent e) {
- if (BugzillaTaskEditor.this.getEditor() instanceof MylarTaskEditor) {
- MylarTaskEditor mylarTaskEditor = (MylarTaskEditor) BugzillaTaskEditor.this.getEditor();
+ if (BugzillaTaskEditor.this.getEditor() instanceof TaskEditor) {
+ TaskEditor mylarTaskEditor = (TaskEditor) BugzillaTaskEditor.this.getEditor();
mylarTaskEditor.displayInBrowser(repository.getUrl() + IBugzillaConstants.URL_VOTE
+ getRepositoryTaskData().getId());
}
diff --git a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/editor/NewBugzillaTaskEditor.java b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/editor/NewBugzillaTaskEditor.java
index d2a4829be..315b556cf 100644
--- a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/editor/NewBugzillaTaskEditor.java
+++ b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/editor/NewBugzillaTaskEditor.java
@@ -16,9 +16,9 @@ import java.net.URLEncoder;
import org.eclipse.mylar.context.core.MylarStatusHandler;
import org.eclipse.mylar.internal.bugzilla.core.BugzillaRepositoryQuery;
import org.eclipse.mylar.internal.bugzilla.ui.BugzillaUiPlugin;
-import org.eclipse.mylar.internal.tasks.ui.editors.AbstractNewRepositoryTaskEditor;
-import org.eclipse.mylar.internal.tasks.ui.search.SearchHitCollector;
import org.eclipse.mylar.tasks.ui.TasksUiPlugin;
+import org.eclipse.mylar.tasks.ui.editors.AbstractNewRepositoryTaskEditor;
+import org.eclipse.mylar.tasks.ui.search.SearchHitCollector;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IEditorSite;
import org.eclipse.ui.forms.editor.FormEditor;
diff --git a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/search/BugzillaSearchPage.java b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/search/BugzillaSearchPage.java
index 6f4dcdb0e..08dae9aa0 100644
--- a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/search/BugzillaSearchPage.java
+++ b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/search/BugzillaSearchPage.java
@@ -30,12 +30,11 @@ import org.eclipse.mylar.internal.bugzilla.core.BugzillaCorePlugin;
import org.eclipse.mylar.internal.bugzilla.core.BugzillaRepositoryQuery;
import org.eclipse.mylar.internal.bugzilla.core.IBugzillaConstants;
import org.eclipse.mylar.internal.bugzilla.ui.BugzillaUiPlugin;
-import org.eclipse.mylar.internal.tasks.ui.search.AbstractRepositoryQueryPage;
-import org.eclipse.mylar.internal.tasks.ui.views.TaskRepositoriesView;
import org.eclipse.mylar.tasks.core.AbstractRepositoryConnector;
import org.eclipse.mylar.tasks.core.TaskRepository;
import org.eclipse.mylar.tasks.core.TaskRepositoryManager;
import org.eclipse.mylar.tasks.ui.TasksUiPlugin;
+import org.eclipse.mylar.tasks.ui.search.AbstractRepositoryQueryPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
@@ -1367,11 +1366,11 @@ public class BugzillaSearchPage extends AbstractRepositoryQueryPage implements L
if (ce.getStatus().getException() instanceof GeneralSecurityException) {
MylarStatusHandler.fail(ce,
"Bugzilla could not log you in to get the information you requested since login name or password is incorrect.\n"
- + "Please ensure proper configuration in " + TaskRepositoriesView.NAME
+ + "Please ensure proper configuration in " + TasksUiPlugin.LABEL_VIEW_REPOSITORIES
+ ". ", true);
} else if (ce.getStatus().getException() instanceof IOException) {
MylarStatusHandler.fail(ce, "Connection Error, please ensure proper configuration in "
- + TaskRepositoriesView.NAME + ".", true);
+ + TasksUiPlugin.LABEL_VIEW_REPOSITORIES + ".", true);
} else {
MylarStatusHandler.fail(ce, "Error updating repository attributes for "
+ repository.getUrl(), true);
diff --git a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/search/IBugzillaResultEditorMatchAdapter.java b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/search/IBugzillaResultEditorMatchAdapter.java
index eba25edf1..a55b99899 100644
--- a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/search/IBugzillaResultEditorMatchAdapter.java
+++ b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/search/IBugzillaResultEditorMatchAdapter.java
@@ -11,7 +11,7 @@
package org.eclipse.mylar.internal.bugzilla.ui.search;
-import org.eclipse.mylar.internal.tasks.ui.search.RepositorySearchResult;
+import org.eclipse.mylar.tasks.ui.search.RepositorySearchResult;
import org.eclipse.search.ui.text.AbstractTextSearchResult;
import org.eclipse.search.ui.text.IEditorMatchAdapter;
import org.eclipse.search.ui.text.Match;
diff --git a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaCustomQueryWizardPage.java b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaCustomQueryWizardPage.java
index 8f90dcfea..2f8067227 100644
--- a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaCustomQueryWizardPage.java
+++ b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaCustomQueryWizardPage.java
@@ -13,9 +13,9 @@ package org.eclipse.mylar.internal.bugzilla.ui.tasklist;
import org.eclipse.mylar.internal.bugzilla.core.BugzillaRepositoryQuery;
import org.eclipse.mylar.internal.tasks.ui.TaskListImages;
-import org.eclipse.mylar.internal.tasks.ui.search.AbstractRepositoryQueryPage;
import org.eclipse.mylar.tasks.core.TaskRepository;
import org.eclipse.mylar.tasks.ui.TasksUiPlugin;
+import org.eclipse.mylar.tasks.ui.search.AbstractRepositoryQueryPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.KeyEvent;
import org.eclipse.swt.events.KeyListener;
diff --git a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaRepositorySettingsPage.java b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaRepositorySettingsPage.java
index 1ac60a655..2cc85b257 100644
--- a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaRepositorySettingsPage.java
+++ b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaRepositorySettingsPage.java
@@ -28,10 +28,10 @@ import org.eclipse.mylar.internal.bugzilla.core.BugzillaClient;
import org.eclipse.mylar.internal.bugzilla.core.BugzillaClientFactory;
import org.eclipse.mylar.internal.bugzilla.core.IBugzillaConstants;
import org.eclipse.mylar.internal.bugzilla.core.RepositoryConfiguration;
-import org.eclipse.mylar.internal.tasks.core.WebClientUtil;
-import org.eclipse.mylar.internal.tasks.ui.wizards.AbstractRepositorySettingsPage;
import org.eclipse.mylar.tasks.core.RepositoryTemplate;
+import org.eclipse.mylar.tasks.core.web.WebClientUtil;
import org.eclipse.mylar.tasks.ui.AbstractRepositoryConnectorUi;
+import org.eclipse.mylar.tasks.ui.wizards.AbstractRepositorySettingsPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
diff --git a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaRepositoryUi.java b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaRepositoryUi.java
index e07a9baf2..1b78af4ac 100644
--- a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaRepositoryUi.java
+++ b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaRepositoryUi.java
@@ -14,16 +14,16 @@ package org.eclipse.mylar.internal.bugzilla.ui.tasklist;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.wizard.IWizard;
import org.eclipse.mylar.internal.bugzilla.core.BugzillaCorePlugin;
-import org.eclipse.mylar.internal.bugzilla.core.BugzillaRepositoryQuery;
import org.eclipse.mylar.internal.bugzilla.core.BugzillaClient;
+import org.eclipse.mylar.internal.bugzilla.core.BugzillaRepositoryQuery;
import org.eclipse.mylar.internal.bugzilla.ui.search.BugzillaSearchPage;
import org.eclipse.mylar.internal.bugzilla.ui.wizard.NewBugzillaTaskWizard;
-import org.eclipse.mylar.internal.tasks.ui.OpenRepositoryTaskJob;
-import org.eclipse.mylar.internal.tasks.ui.search.AbstractRepositoryQueryPage;
-import org.eclipse.mylar.internal.tasks.ui.wizards.AbstractRepositorySettingsPage;
import org.eclipse.mylar.tasks.core.AbstractRepositoryQuery;
import org.eclipse.mylar.tasks.core.TaskRepository;
import org.eclipse.mylar.tasks.ui.AbstractRepositoryConnectorUi;
+import org.eclipse.mylar.tasks.ui.OpenRepositoryTaskJob;
+import org.eclipse.mylar.tasks.ui.search.AbstractRepositoryQueryPage;
+import org.eclipse.mylar.tasks.ui.wizards.AbstractRepositorySettingsPage;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PlatformUI;
diff --git a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaTaskEditorFactory.java b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaTaskEditorFactory.java
index 9b27671ac..f49115822 100644
--- a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaTaskEditorFactory.java
+++ b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaTaskEditorFactory.java
@@ -19,16 +19,15 @@ import org.eclipse.mylar.internal.bugzilla.core.BugzillaCorePlugin;
import org.eclipse.mylar.internal.bugzilla.core.BugzillaTask;
import org.eclipse.mylar.internal.bugzilla.ui.editor.BugzillaTaskEditor;
import org.eclipse.mylar.internal.bugzilla.ui.editor.NewBugzillaTaskEditor;
-import org.eclipse.mylar.internal.tasks.ui.ITaskEditorFactory;
-import org.eclipse.mylar.internal.tasks.ui.editors.AbstractRepositoryTaskEditor;
-import org.eclipse.mylar.internal.tasks.ui.editors.MylarTaskEditor;
-import org.eclipse.mylar.internal.tasks.ui.editors.NewTaskEditorInput;
-import org.eclipse.mylar.internal.tasks.ui.editors.RepositoryTaskEditorInput;
-import org.eclipse.mylar.internal.tasks.ui.editors.TaskEditorInput;
-import org.eclipse.mylar.internal.tasks.ui.views.TaskRepositoriesView;
import org.eclipse.mylar.tasks.core.ITask;
import org.eclipse.mylar.tasks.core.TaskRepository;
import org.eclipse.mylar.tasks.ui.TasksUiPlugin;
+import org.eclipse.mylar.tasks.ui.editors.AbstractRepositoryTaskEditor;
+import org.eclipse.mylar.tasks.ui.editors.ITaskEditorFactory;
+import org.eclipse.mylar.tasks.ui.editors.NewTaskEditorInput;
+import org.eclipse.mylar.tasks.ui.editors.RepositoryTaskEditorInput;
+import org.eclipse.mylar.tasks.ui.editors.TaskEditor;
+import org.eclipse.mylar.tasks.ui.editors.TaskEditorInput;
import org.eclipse.swt.widgets.Display;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.PlatformUI;
@@ -42,7 +41,7 @@ public class BugzillaTaskEditorFactory implements ITaskEditorFactory {
private static final String TITLE = "Bugzilla";
- public EditorPart createEditor(MylarTaskEditor parentEditor, IEditorInput editorInput) {
+ public EditorPart createEditor(TaskEditor parentEditor, IEditorInput editorInput) {
AbstractRepositoryTaskEditor editor = null;
if (editorInput instanceof RepositoryTaskEditorInput || editorInput instanceof TaskEditorInput) {
editor = new BugzillaTaskEditor(parentEditor);
@@ -66,7 +65,7 @@ public class BugzillaTaskEditorFactory implements ITaskEditorFactory {
PlatformUI.getWorkbench().getDisplay().asyncExec(new Runnable() {
public void run() {
MessageDialog.openError(Display.getDefault().getActiveShell(), "Report Download Failed",
- "Ensure proper repository configuration in " + TaskRepositoriesView.NAME + ".\n"
+ "Ensure proper repository configuration in " + TasksUiPlugin.LABEL_VIEW_REPOSITORIES + ".\n"
+ "Repository set to: " + repository.getUrl() + ", username: "
+ repository.getUserName());
}
diff --git a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaTaskEditorInput.java b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaTaskEditorInput.java
index e193a4bd6..519d28a33 100644
--- a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaTaskEditorInput.java
+++ b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaTaskEditorInput.java
@@ -20,11 +20,11 @@ import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.mylar.internal.bugzilla.core.BugzillaCorePlugin;
import org.eclipse.mylar.internal.bugzilla.core.BugzillaRepositoryConnector;
import org.eclipse.mylar.internal.bugzilla.core.BugzillaTask;
-import org.eclipse.mylar.internal.tasks.ui.editors.RepositoryTaskEditorInput;
import org.eclipse.mylar.tasks.core.RepositoryTaskAttribute;
import org.eclipse.mylar.tasks.core.RepositoryTaskData;
import org.eclipse.mylar.tasks.core.TaskRepository;
import org.eclipse.mylar.tasks.ui.TasksUiPlugin;
+import org.eclipse.mylar.tasks.ui.editors.RepositoryTaskEditorInput;
import org.eclipse.ui.IPersistableElement;
/**
diff --git a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaTaskExternalizer.java b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaTaskExternalizer.java
index 14e81d145..2b0c076c3 100644
--- a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaTaskExternalizer.java
+++ b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/BugzillaTaskExternalizer.java
@@ -22,11 +22,8 @@ import org.eclipse.mylar.tasks.core.AbstractRepositoryTask;
import org.eclipse.mylar.tasks.core.AbstractTaskContainer;
import org.eclipse.mylar.tasks.core.DelegatingTaskExternalizer;
import org.eclipse.mylar.tasks.core.ITask;
-import org.eclipse.mylar.tasks.core.RepositoryTaskData;
import org.eclipse.mylar.tasks.core.TaskExternalizationException;
import org.eclipse.mylar.tasks.core.TaskList;
-import org.eclipse.mylar.tasks.core.AbstractRepositoryTask.RepositoryTaskSyncState;
-import org.eclipse.mylar.tasks.ui.TasksUiPlugin;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
@@ -159,17 +156,6 @@ public class BugzillaTaskExternalizer extends DelegatingTaskExternalizer {
return task;
}
- // TODO move to DelegatingTaskExternalizer
- @Override
- public void readTaskData(AbstractRepositoryTask task) {
- RepositoryTaskData data = TasksUiPlugin.getDefault().getTaskDataManager().getTaskData(task.getHandleIdentifier());
- task.setTaskData(data);
-
- if (data != null && data.hasLocalChanges()) {
- task.setSyncState(RepositoryTaskSyncState.OUTGOING);
- }
- }
-
@Override
public boolean canReadQueryHit(Node node) {
return node.getNodeName().equals(getQueryHitTagName());
diff --git a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/EditBugzillaQueryWizard.java b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/EditBugzillaQueryWizard.java
index 9802d9c2d..b89818d04 100644
--- a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/EditBugzillaQueryWizard.java
+++ b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/EditBugzillaQueryWizard.java
@@ -13,8 +13,8 @@ package org.eclipse.mylar.internal.bugzilla.ui.tasklist;
import org.eclipse.mylar.internal.bugzilla.core.BugzillaRepositoryQuery;
import org.eclipse.mylar.internal.bugzilla.ui.search.BugzillaSearchPage;
-import org.eclipse.mylar.internal.tasks.ui.wizards.AbstractEditQueryWizard;
import org.eclipse.mylar.tasks.core.TaskRepository;
+import org.eclipse.mylar.tasks.ui.wizards.AbstractEditQueryWizard;
/**
* @author Rob Elves
diff --git a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/NewBugzillaQueryWizard.java b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/NewBugzillaQueryWizard.java
index c82b48f19..8df6988cc 100644
--- a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/NewBugzillaQueryWizard.java
+++ b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/tasklist/NewBugzillaQueryWizard.java
@@ -17,10 +17,10 @@ import org.eclipse.jface.wizard.Wizard;
import org.eclipse.mylar.context.core.MylarStatusHandler;
import org.eclipse.mylar.internal.bugzilla.core.BugzillaCorePlugin;
import org.eclipse.mylar.internal.bugzilla.core.BugzillaRepositoryQuery;
-import org.eclipse.mylar.internal.tasks.ui.search.AbstractRepositoryQueryPage;
import org.eclipse.mylar.tasks.core.AbstractRepositoryConnector;
import org.eclipse.mylar.tasks.core.TaskRepository;
import org.eclipse.mylar.tasks.ui.TasksUiPlugin;
+import org.eclipse.mylar.tasks.ui.search.AbstractRepositoryQueryPage;
import org.eclipse.ui.actions.WorkspaceModifyOperation;
/**
diff --git a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/wizard/BugzillaProductPage.java b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/wizard/BugzillaProductPage.java
index 1f3ce5dd6..46035f873 100644
--- a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/wizard/BugzillaProductPage.java
+++ b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/wizard/BugzillaProductPage.java
@@ -55,9 +55,8 @@ import org.eclipse.mylar.internal.bugzilla.core.BugzillaRepositoryConnector;
import org.eclipse.mylar.internal.bugzilla.core.BugzillaRepositoryQuery;
import org.eclipse.mylar.internal.bugzilla.core.BugzillaTask;
import org.eclipse.mylar.internal.bugzilla.core.IBugzillaConstants;
-import org.eclipse.mylar.internal.bugzilla.core.NewBugzillaReport;
+import org.eclipse.mylar.internal.bugzilla.core.NewBugzillaTaskData;
import org.eclipse.mylar.internal.bugzilla.ui.BugzillaUiPlugin;
-import org.eclipse.mylar.internal.tasks.ui.views.TaskRepositoriesView;
import org.eclipse.mylar.tasks.core.AbstractRepositoryConnector;
import org.eclipse.mylar.tasks.core.ITask;
import org.eclipse.mylar.tasks.core.RepositoryTaskAttribute;
@@ -264,11 +263,11 @@ public class BugzillaProductPage extends WizardPage {
MylarStatusHandler.fail(ce,
"Bugzilla could not log you in to get the information you requested since login name or password is incorrect.\n"
+ "Please ensure proper configuration in "
- + TaskRepositoriesView.NAME + ". ", true);
+ + TasksUiPlugin.LABEL_VIEW_REPOSITORIES + ". ", true);
} else if (ce.getStatus().getException() instanceof IOException) {
MylarStatusHandler.fail(ce,
"Connection Error, please ensure proper configuration in "
- + TaskRepositoriesView.NAME + ".", true);
+ + TasksUiPlugin.LABEL_VIEW_REPOSITORIES + ".", true);
} else {
MylarStatusHandler.fail(ce, "Error updating repository attributes for "
+ repository.getUrl(), true);
@@ -303,7 +302,7 @@ public class BugzillaProductPage extends WizardPage {
private void initProducts() {
// try to get the list of products from the server
- if (!bugWizard.model.hasParsedProducts()) {
+ if (!bugWizard.taskData.hasParsedProducts()) {
String repositoryUrl = repository.getUrl();
try {
String[] storedProducts = BugzillaUiPlugin.getQueryOptions(IBugzillaConstants.VALUES_PRODUCT, null,
@@ -314,16 +313,16 @@ public class BugzillaProductPage extends WizardPage {
products = BugzillaCorePlugin.getRepositoryConfiguration(repository, false)
.getProducts();
}
- bugWizard.model.setConnected(true);
- bugWizard.model.setParsedProductsStatus(true);
+ bugWizard.taskData.setConnected(true);
+ bugWizard.taskData.setParsedProductsStatus(true);
} catch (final Exception e) {
- bugWizard.model.setConnected(false);
+ bugWizard.taskData.setConnected(false);
PlatformUI.getWorkbench().getDisplay().asyncExec(new Runnable() {
public void run() {
MessageDialog.openError(Display.getDefault().getActiveShell(), NEW_BUGZILLA_TASK_ERROR_TITLE,
"Unable to get products. Ensure proper repository configuration in "
- + TaskRepositoriesView.NAME + ".\n\n");
+ + TasksUiPlugin.LABEL_VIEW_REPOSITORIES + ".\n\n");
MylarStatusHandler.log(e, "Failed to retrieve products from server");
}
});
@@ -429,7 +428,7 @@ public class BugzillaProductPage extends WizardPage {
}
/**
* Save the currently selected product to the model when next is clicked
*
* @throws IOException
* @throws NoSuchAlgorithmException
@@ -438,7 +437,7 @@ public class BugzillaProductPage extends WizardPage {
* @throws BugzillaException
*/
public void saveDataToModel() throws CoreException {
- NewBugzillaReport model = bugWizard.model;
+ NewBugzillaTaskData model = bugWizard.taskData;
prevProduct = model.getProduct();
model.setProduct((String) ((IStructuredSelection) productList.getViewer().getSelection()).getFirstElement());
@@ -456,7 +455,7 @@ public class BugzillaProductPage extends WizardPage {
return bugWizard.completed;
}
- public void setPlatformOptions(NewBugzillaReport newBugModel) {
+ public void setPlatformOptions(NewBugzillaTaskData newBugModel) {
try {
// Get OS Lookup Map
@@ -502,7 +501,7 @@ public class BugzillaProductPage extends WizardPage {
bugzillaPlatform = null;
}
- // Set the OS and the Platform in the model
+ // Set the OS and the Platform in the taskData
if (bugzillaOS != null && opSysAttribute != null) {
opSysAttribute.setValue(bugzillaOS);
} else if (opSysAttribute != null && opSysAttribute.getOptionParameter(OPTION_ALL) != null) {
@@ -522,21 +521,21 @@ public class BugzillaProductPage extends WizardPage {
// @Override
// public IWizardPage getNextPage() {
// // save the product information to the model
// saveDataToModel();
// NewBugzillaTaskWizard wizard = (NewBugzillaTaskWizard) getWizard();
- // NewBugzillaReport model = wizard.model;
+ // NewBugzillaTaskData taskData = wizard.model;
//
// // try to get the attributes from the bugzilla server
// try {
- // if (!model.hasParsedAttributes() ||
- // !model.getProduct().equals(prevProduct)) {
+ // if (!taskData.hasParsedAttributes() ||
+ // !taskData.getProduct().equals(prevProduct)) {
// BugzillaRepositoryUtil.setupNewBugAttributes(repository.getUrl(),
// MylarTaskListPlugin.getDefault()
// .getProxySettings(), repository.getUserName(), repository.getPassword(),
- // model, repository
+ // taskData, repository
// .getCharacterEncoding());
- // model.setParsedAttributesStatus(true);
+ // taskData.setParsedAttributesStatus(true);
// }
//
// // if (prevProduct == null) {
@@ -544,7 +543,7 @@ public class BugzillaProductPage extends WizardPage {
// // bugWizard.addPage(bugWizard.getAttributePage());
// // } else {
// // // selected product has changed
// // // will createControl again with new attributes in model
// // bugWizard.getAttributePage().setControl(null);
// // }
//
@@ -429,7 +428,7 @@ public class BugzillaProductPage extends WizardPage {
}
/**
- * Save the currently selected product to the model when next is clicked
+ * Save the currently selected product to the taskData when next is clicked
*
* @throws IOException
@@ -522,21 +521,21 @@ public class BugzillaProductPage extends WizardPage {
// @Override
// public IWizardPage getNextPage() {
- // // save the product information to the model
+ // // save the product information to the taskData
// saveDataToModel();
// NewBugzillaTaskWizard wizard = (NewBugzillaTaskWizard) getWizard();
@@ -544,7 +543,7 @@ public class BugzillaProductPage extends WizardPage {
// // } else {
// // // selected product has changed
- // // // will createControl again with new attributes in model
+ // // // will createControl again with new attributes in taskData
// // bugWizard.getAttributePage().setControl(null);
// // }
diff --git a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/wizard/NewBugzillaTaskWizard.java b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/wizard/NewBugzillaTaskWizard.java
index b72c1f92f..6e921a87a 100644
--- a/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/wizard/NewBugzillaTaskWizard.java
+++ b/org.eclipse.mylyn.bugzilla.ui/src/org/eclipse/mylyn/internal/bugzilla/ui/wizard/NewBugzillaTaskWizard.java
@@ -14,13 +14,13 @@ import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.wizard.Wizard;
-import org.eclipse.mylar.internal.bugzilla.core.NewBugzillaReport;
+import org.eclipse.mylar.internal.bugzilla.core.NewBugzillaTaskData;
import org.eclipse.mylar.internal.bugzilla.ui.BugzillaUiPlugin;
import org.eclipse.mylar.internal.tasks.ui.TaskListPreferenceConstants;
-import org.eclipse.mylar.internal.tasks.ui.TasksUiUtil;
-import org.eclipse.mylar.internal.tasks.ui.editors.NewTaskEditorInput;
import org.eclipse.mylar.tasks.core.TaskRepository;
import org.eclipse.mylar.tasks.ui.TasksUiPlugin;
+import org.eclipse.mylar.tasks.ui.TasksUiUtil;
+import org.eclipse.mylar.tasks.ui.editors.NewTaskEditorInput;
import org.eclipse.ui.INewWizard;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPage;
@@ -45,16 +45,15 @@ public class NewBugzillaTaskWizard extends Wizard implements INewWizard {
*/
protected boolean completed = false;
- /** The model used to store all of the data for the wizard */
- protected NewBugzillaReport model;
+ /** The taskData used to store all of the data for the wizard */
+ protected NewBugzillaTaskData taskData;
- // TODO: Change model to a RepositoryTaskData
- // protected RepositoryTaskData model;
+ // TODO: Change taskData to a RepositoryTaskData
+ // protected RepositoryTaskData taskData;
public NewBugzillaTaskWizard(TaskRepository repository) {
this(false, repository);
- model = new NewBugzillaReport(repository.getUrl(), TasksUiPlugin.getDefault().getTaskDataManager()
- .getNewRepositoryTaskId());
+ taskData = new NewBugzillaTaskData(repository.getUrl(), TasksUiPlugin.getDefault().getNextNewRepositoryTaskId());
super.setDefaultPageImageDescriptor(BugzillaUiPlugin.imageDescriptorFromPlugin(
"org.eclipse.mylar.internal.bugzilla.ui", "icons/wizban/bug-wizard.gif"));
super.setWindowTitle(TITLE);
@@ -87,7 +86,7 @@ public class NewBugzillaTaskWizard extends Wizard implements INewWizard {
try {
productPage.saveDataToModel();
- NewTaskEditorInput editorInput = new NewTaskEditorInput(repository, model);
+ NewTaskEditorInput editorInput = new NewTaskEditorInput(repository, taskData);
IWorkbenchPage page = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage();
TasksUiUtil.openEditor(editorInput, TaskListPreferenceConstants.TASK_EDITOR_ID, page);
return true;
@@ -105,7 +104,7 @@ public class NewBugzillaTaskWizard extends Wizard implements INewWizard {
// // AbstractRepositoryConnector client = (AbstractRepositoryConnector)
// // MylarTaskListPlugin.getRepositoryManager()
// // .getRepositoryConnector(BugzillaPlugin.REPOSITORY_KIND);
-// // client.saveOffline(model);
+// // client.saveOffline(taskData);
// }
//
// @Override

Back to the top